==> ejc-sealm-impl-3.0.0-20220614.100844-97-sources.jar: com/ejianc/business/sealm/service/impl/ZzyzServiceImpl.java <==
package com.ejianc.business.sealm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.sealm.vo.ContractVO;
import com.ejianc.business.sealm.vo.ZzyzVO;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.sealm.mapper.ZzyzMapper;
import com.ejianc.business.sealm.bean.ZzyzEntity;
import com.ejianc.business.sealm.service.IZzyzService;

import java.util.List;

/**
 * 组织印章
 * 
 * @author generator
 * 
 */
@Service("zzyzService")
public class ZzyzServiceImpl extends BaseServiceImpl<ZzyzMapper, ZzyzEntity> implements IZzyzService{
    public List<ZzyzVO> queryStoreInstoreData(Page<ZzyzVO> page, QueryWrapper wrapper) {
        return baseMapper.queryStoreInstoreData(page, wrapper);
    }

    @Override
    public List<ContractVO> queryJxsbcgData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.queryJxsbcgData(page, wrapper);
    }


    @Override
    public List<ContractVO> queryJxsbzlData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.queryJxsbzlData(page, wrapper);
    }

    @Override
    public List<ContractVO> queryJxsbacData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.queryJxsbacData(page, wrapper);
    }

    @Override
    public List<ContractVO> refSghtData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refSghtData(page, wrapper);
    }


    @Override
    public List<ContractVO> refClcgData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refClcgData(page, wrapper);
    }

    @Override
    public List<ContractVO> refFbData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refFbData(page, wrapper);
    }

    @Override
    public List<ContractVO> refQtzcData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refQtzcData(page, wrapper);
    }

    @Override
    public List<ContractVO> refZzcData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refZzcData(page, wrapper);
    }
}

==> ejc-sealm-impl-3.0.0-20230905.100230-138-sources.jar: com/ejianc/business/sealm/service/impl/ZzyzServiceImpl.java <==
package com.ejianc.business.sealm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.sealm.vo.ContractVO;
import com.ejianc.business.sealm.vo.ZzyzVO;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.sealm.mapper.ZzyzMapper;
import com.ejianc.business.sealm.bean.ZzyzEntity;
import com.ejianc.business.sealm.service.IZzyzService;

import java.util.List;

/**
 * 组织印章
 * 
 * @author generator
 * 
 */
@Service("zzyzService")
public class ZzyzServiceImpl extends BaseServiceImpl<ZzyzMapper, ZzyzEntity> implements IZzyzService{
    public List<ZzyzVO> queryStoreInstoreData(Page<ZzyzVO> page, QueryWrapper wrapper) {
        return baseMapper.queryStoreInstoreData(page, wrapper);
    }

    @Override
    public List<ContractVO> queryJxsbcgData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.queryJxsbcgData(page, wrapper);
    }


    @Override
    public List<ContractVO> queryJxsbzlData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.queryJxsbzlData(page, wrapper);
    }

    @Override
    public List<ContractVO> queryJxsbacData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.queryJxsbacData(page, wrapper);
    }

    @Override
    public List<ContractVO> refSghtData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refSghtData(page, wrapper);
    }


    @Override
    public List<ContractVO> refClcgData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refClcgData(page, wrapper);
    }

    @Override
    public List<ContractVO> refFbData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refFbData(page, wrapper);
    }

    @Override
    public List<ContractVO> refQtzcData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refQtzcData(page, wrapper);
    }
    @Override
    public List<ContractVO> refQtzc1Data(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refQtzc1Data(page, wrapper);
    }
    @Override
    public List<ContractVO> refZzcData(Page<ContractVO> page, QueryWrapper wrapper) {
        return baseMapper.refZzcData(page, wrapper);
    }
}
